<?php

namespace Eform\Faq\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Faq\Events\FaqWorkflow as FaqWorkflowEvent;
use Eform\Faq\Notifications\FaqWorkflow as FaqWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class FaqWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(FaqWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $faq is submitted.
     *
     * @param FaqWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(FaqWorkflowEvent $event)
    {
        $client = $event->faq->client;
        Notification::send($client, new FaqWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $faq is published.
     *
     * @param FaqWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(FaqWorkflowEvent $event)
    {
        $client = $event->faq->client;
        Notification::send($client, new FaqWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $faq is approved.
     *
     * @param FaqWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(FaqWorkflowEvent $event)
    {
        $client = $event->faq->client;
        Notification::send($client, new FaqWorkflowNotification($event));
    }

    /**
     * Handles the $faq workflow event as a listener.
     *
     * @param FaqWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(FaqWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
