<?php

namespace Eform\Faq\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Eform\Faq\Models\Faq;

class FaqPolicy
{

    use FaqAction;
    use FaqExim;

    /**
     * Determine if the given user can view the faq.
     *
     * @param Authenticatable $user
     * @param Faq $faq
     *
     * @return bool
     */
    public function view(Authenticatable $user, Faq $faq)
    {
        if ($authUser->canDo('faq.faq.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $faq->is_owner;
    }

    /**
     * Determine if the given user can create a faq.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('faq.faq.create');
    }

    /**
     * Determine if the given user can update the given faq.
     *
     * @param Authenticatable $user
     * @param Faq $faq
     *
     * @return bool
     */
    public function update(Authenticatable $user, Faq $faq)
    {
        if ($user->canDo('faq.faq.edit') && $user->isAdmin()) {
            return true;
        }

        return $faq->is_owner;
    }

    /**
     * Determine if the given user can delete the given faq.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Faq $faq)
    {
        return $faq->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
